/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ViewContainerRef } from '@angular/core';
import { AdaptiveGridService } from '../common/adaptiveness.service';
import { ActionSheetComponent } from '@progress/kendo-angular-navigation';
import { FilterMenuContainerComponent } from '../filtering/menu/filter-menu-container.component';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { FilterService } from '../filtering/filter.service';
import { ColumnMenuService } from '../column-menu/column-menu.service';
import { ColumnListComponent } from '../column-menu/column-list.component';
import { ContextService } from '../common/provider.service';
import { AdaptiveService } from '@progress/kendo-angular-utils';
import { SortService } from '../common/sort.service';
import { ColumnComponent } from '../columns/column.component';
import { ColumnInfoService } from '../common/column-info.service';
import { ColumnBase } from '../columns/column-base';
import { SortDescriptor } from '@progress/kendo-data-query';
import { GroupToolbarToolComponent } from '../rendering/toolbar/tools/group-toolbar-tool.component';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class AdaptiveRendererComponent {
    service: ColumnMenuService;
    adaptiveGridService: AdaptiveGridService;
    private filterService;
    ctx: ContextService;
    adaptiveService: AdaptiveService;
    private sortService;
    private columnInfoService;
    xIcon: SVGIcon;
    checkIcon: SVGIcon;
    filterIcon: SVGIcon;
    arrowRotateCcwIcon: SVGIcon;
    chevronLeft: SVGIcon;
    filterClearIcon: SVGIcon;
    cancelIcon: SVGIcon;
    saveIcon: SVGIcon;
    columns: Array<ColumnBase>;
    actionsClass: string;
    externalEditingSettings: any;
    get hasSort(): boolean;
    get hasColumnChooser(): boolean;
    get hasFilter(): boolean;
    get hasAutoSizeColumn(): boolean;
    get hasAutoSizeAllColumns(): boolean;
    get hasLock(): boolean;
    get hasStick(): boolean;
    get hasPosition(): boolean;
    getColumnComponent(column: ColumnBase): ColumnComponent;
    get hasTitle(): boolean;
    get hasSubtitle(): boolean;
    get actionSheetTitle(): string;
    get adaptiveFilterTitle(): string;
    get columnMenuTitle(): string;
    get filterLabel(): string;
    get hasXCloseIcon(): boolean;
    get hasCheckCloseIcon(): boolean;
    columnList: ColumnListComponent;
    filterToolbarToolTemplate: ViewContainerRef;
    filterMenuContainer: FilterMenuContainerComponent;
    actionSheet: ActionSheetComponent;
    set groupToolbarTool(value: GroupToolbarToolComponent);
    private adaptiveSizeChangeSubscription;
    constructor(service: ColumnMenuService, adaptiveGridService: AdaptiveGridService, filterService: FilterService, ctx: ContextService, adaptiveService: AdaptiveService, sortService: SortService, columnInfoService: ColumnInfoService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    messageFor: (token: string) => string;
    close(): void;
    prevView(): void;
    clearFilters(): void;
    navigateToColumnsView(): void;
    navigateToFilterView(): void;
    navigateToPositionView(): void;
    applyChanges(): void;
    sortBy(column: ColumnBase): void;
    toggleSort(column: ColumnBase): void;
    getDescriptor(column: ColumnBase): SortDescriptor[];
    clearSorting(): void;
    clearGrouping(): void;
    onAnimationEnd(): void;
    cancelChanges(): void;
    onTab(event: KeyboardEvent): void;
    saveEditing(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AdaptiveRendererComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AdaptiveRendererComponent, "kendo-grid-adaptive-renderer", never, {}, {}, never, never, true, never>;
}
