/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Renderer2 } from '@angular/core';
import { SortService } from '../common/sort.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item for sorting Grid columns.
 * [See example](slug:columnmenu_grid#toc-sort-item).
 *
 * The component can be placed inside a [ColumnMenuTemplate]({% slug api_grid_columnmenutemplatedirective %}) directive.
 * To register the component as a known column menu item, set the [ColumnMenuService]({% slug api_grid_columnmenuservice %}) that is passed by
 * the template to the service input of the `kendo-grid-columnmenu-sort` component. [See example](slug:columnmenu_grid#toc-customizing-the-content).
 *
 * You have to set the [ColumnMenuService]({% slug api_grid_columnmenuservice %}) that is passed by
 * the template to the service input of the `kendo-grid-columnmenu-sort` component.
 *
 * @example
 * ```html
 * <kendo-grid [kendoGridBinding]="data" [sortable]="true" [columnMenu]="true">
 *   <ng-template kendoGridColumnMenuTemplate let-service="service">
 *     <kendo-grid-columnmenu-sort [service]="service">
 *     </kendo-grid-columnmenu-sort>
 *   </ng-template>
 * </kendo-grid>
 * ```
 */
export declare class ColumnMenuSortComponent extends ColumnMenuItemBase {
    ctx: ContextService;
    protected sortService: SortService;
    protected renderer: Renderer2;
    sortAscSmallIcon: SVGIcon;
    sortDescSmallIcon: SVGIcon;
    constructor(ctx: ContextService, sortService: SortService, renderer: Renderer2);
    get sortedAsc(): boolean;
    get sortedDesc(): boolean;
    /**
     * @hidden
     */
    toggleSort(dir: string): void;
    private get descriptor();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuSortComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuSortComponent, "kendo-grid-columnmenu-sort", never, {}, {}, never, never, true, never>;
}
