/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { MenuTabbingService } from './../filtering/menu/menu-tabbing.service';
import { EventEmitter } from '@angular/core';
import type { ColumnMenuContainerComponent } from './column-menu-container.component';
import * as i0 from "@angular/core";
/**
 * Represents the service that is passed to the
 * [ColumnMenuTemplate]({% slug api_grid_columnmenutemplatedirective %}) directive.
 *
 * @example
 * ```html
 * <kendo-grid [data]="data" [columnMenu]="true">
 *    <ng-template kendoGridColumnMenuTemplate let-service="service">
 *       <span class="k-icon k-font-icon k-i-x" (click)="service.close()" </span>
 *       <kendo-grid-columnmenu-sort [service]="service">
 *       </kendo-grid-columnmenu-sort>
 *    </ng-template>
 *    <kendo-grid-column field="Field1"></kendo-grid-column>
 * </kendo-grid>
 *
 * ```
 */
export declare class ColumnMenuService {
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    /**
     * @hidden
     */
    closeMenu: EventEmitter<any>;
    /**
     * @hidden
     */
    column: any;
    /**
     * @hidden
     */
    sort: any;
    /**
     * @hidden
     */
    filter: any;
    /**
     * @hidden
     */
    sortable: any;
    /**
     * @hidden
     */
    columnMenuContainer: ColumnMenuContainerComponent;
    /**
     * @hidden
     */
    constructor(menuTabbingService?: MenuTabbingService);
    /**
     * Closes the column menu.
     */
    close(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ColumnMenuService>;
}
