/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { QueryList, TemplateRef } from '@angular/core';
import { ColumnBase } from './column-base';
import { IdService } from '../common/id.service';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { RowDragHandleTemplateDirective } from '../row-reordering/drag-handle-template.directive';
import { RowDragHintTemplateDirective } from '../row-reordering/drag-hint-template.directive';
import { CellRowspanFn } from './cell-rowspan';
import * as i0 from "@angular/core";
/**
 * Represents the drag handle for reordering rows in the Grid ([see example](slug:reordering_rows_grid))
 */
export declare class RowReorderColumnComponent extends ColumnBase {
    parent?: ColumnBase;
    /**
     * Defines the name for an existing font icon in the Kendo UI theme.
     * @hidden
     */
    dragHandleIcon: string;
    /**
     * Defines an SVGIcon to be rendered as a drag handle.
     * @hidden
     */
    dragHandleSVGIcon: SVGIcon;
    /**
     * @hidden
     */
    dragHandleTemplate: QueryList<RowDragHandleTemplateDirective>;
    /**
     * @hidden
     */
    dragHintTemplate: QueryList<RowDragHintTemplateDirective>;
    /**
     * @hidden
     */
    readonly isRowReorderColumn: boolean;
    /**
     * @hidden
     */
    get rowDragHandleTemplateRef(): TemplateRef<any>;
    /**
     * @hidden
     */
    get rowDragHintTemplateRef(): TemplateRef<any>;
    constructor(parent?: ColumnBase, idService?: IdService);
    /**
     * Defines a function that is used to determine the rowspan of each column cell.
     */
    set cellRowspan(cellRowspan: CellRowspanFn);
    get cellRowspan(): CellRowspanFn;
    static ɵfac: i0.ɵɵFactoryDeclaration<RowReorderColumnComponent, [{ optional: true; host: true; skipSelf: true; }, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RowReorderColumnComponent, "kendo-grid-rowreorder-column", never, { "dragHandleIcon": { "alias": "dragHandleIcon"; "required": false; }; "dragHandleSVGIcon": { "alias": "dragHandleSVGIcon"; "required": false; }; }, {}, ["dragHandleTemplate", "dragHintTemplate"], never, true, never>;
}
