/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ComponentRef } from "@angular/core";
import { Observable } from "rxjs";
import { AdaptiveService, AdaptiveSize } from "@progress/kendo-angular-utils";
import { PopupRef } from "@progress/kendo-angular-popup";
import { DialogRef } from "@progress/kendo-angular-dialog";
import { ColumnComponent } from "../columns/column.component";
import { ContextService } from "./provider.service";
import { FilterMenuContainerComponent } from "../filtering/menu/filter-menu-container.component";
import { ColumnMenuService } from "../column-menu/column-menu.service";
import * as i0 from "@angular/core";
type AdaptiveView = 'columnMenu' | 'filterMenu' | 'sortToolbarTool' | 'filterToolbarTool' | 'columnChooserToolbarTool' | 'groupToolbarTool' | 'externalEditing';
type SecondaryView = 'columnChooser' | 'columnPosition' | 'columnFilter';
/**
 * @hidden
 *
 * The AdaptiveGridService is used to provide common information for the ActionSheet used in adaptive mode.
 */
export declare class AdaptiveGridService {
    private ctx;
    private adaptiveService;
    /**
     * Observable that emits when the ActionSheet's views change animation ends.
     */
    get animationEnd(): Observable<void>;
    columnMenuService: ColumnMenuService;
    columns: ColumnComponent[];
    secondaryView: SecondaryView;
    viewType: AdaptiveView;
    popupRef: PopupRef | DialogRef;
    column: ColumnComponent;
    filterMenuContainer: FilterMenuContainerComponent;
    filterMenuContainerComponentRef: ComponentRef<FilterMenuContainerComponent>;
    private animationEndSubject;
    constructor(ctx: ContextService, adaptiveService: AdaptiveService);
    submitFilter(): void;
    resetFilter(): void;
    reset(): void;
    /**
     * Emits an event to notify that the animation has ended.
     */
    notifyAnimationEnd(): void;
    get windowSize(): AdaptiveSize;
    static ɵfac: i0.ɵɵFactoryDeclaration<AdaptiveGridService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AdaptiveGridService>;
}
export {};
