/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, YearViewService, NavigationService } from '@progress/kendo-angular-dateinputs';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_GRID_BODY_EXPORTS, KENDO_GRID_COLUMN_MENU_DECLARATIONS, KENDO_GRID_DECLARATIONS, KENDO_GRID_EXPORTS, KENDO_GRID_FILTER_MENU, KENDO_GRID_FILTER_ROW, KENDO_GRID_FOOTER_EXPORTS, KENDO_GRID_GROUP_EXPORTS, KENDO_GRID_HEADER_EXPORTS, KENDO_GRID_SHARED } from './directives';
import { TableDirective } from './column-resizing/table.directive';
import { KENDO_PAGER } from '@progress/kendo-angular-pager';
import { KENDO_TOOLBAR } from '@progress/kendo-angular-toolbar';
import { UndoCommandToolbarDirective } from './state-management/undo-command-tool';
import { RedoCommandToolbarDirective } from './state-management/redo-command-tool';
import * as i0 from "@angular/core";
import * as i1 from "./grouping/group-header-template.directive";
import * as i2 from "./grouping/group-header-column-template.directive";
import * as i3 from "./grouping/group-footer-template.directive";
import * as i4 from "./grouping/group-header.component";
import * as i5 from "./grouping/group-panel.component";
import * as i6 from "./columns/column.component";
import * as i7 from "./columns/column-group.component";
import * as i8 from "./navigation/logical-cell.directive";
import * as i9 from "./navigation/logical-row.directive";
import * as i10 from "./navigation/focusable.directive";
import * as i11 from "./rendering/footer/footer-template.directive";
import * as i12 from "./rendering/common/col-group.component";
import * as i13 from "./layout/resizable.directive";
import * as i14 from "@progress/kendo-angular-common";
import * as i15 from "./rendering/common/field-accessor.pipe";
import * as i16 from "./rendering/details/detail-template.directive";
import * as i17 from "./columns/span-column.component";
import * as i18 from "./rendering/common/loading.component";
import * as i19 from "./rendering/grid-table.directive";
import * as i20 from "./columns/command-column.component";
import * as i21 from "./columns/checkbox-column.component";
import * as i22 from "./selection/selection-checkbox.directive";
import * as i23 from "./rendering/cell-template.directive";
import * as i24 from "./editing/edit-template.directive";
import * as i25 from "./row-reordering/drag-handle-template.directive";
import * as i26 from "./row-reordering/drag-hint-template.directive";
import * as i27 from "./rendering/table-body.component";
import * as i28 from "./rendering/no-records-template.directive";
import * as i29 from "./rendering/cell.component";
import * as i30 from "./editing/edit-command.directive";
import * as i31 from "./editing/cancel-command.directive";
import * as i32 from "./editing/save-command.directive";
import * as i33 from "./editing/remove-command.directive";
import * as i34 from "./editing/add-command.directive";
import * as i35 from "./editing/add-command-tool.directive";
import * as i36 from "./editing/edit-command-tool.directive";
import * as i37 from "./editing/save-command-tool.directive";
import * as i38 from "./editing/remove-command-tool.directive";
import * as i39 from "./editing/cancel-command-tool.directive";
import * as i40 from "./rendering/cell-loading.template.directive";
import * as i41 from "./rendering/loading-template.directive";
import * as i42 from "./columns/reorder-column.component";
import * as i43 from "./rendering/toolbar/tools/sort-command-tool.directive";
import * as i44 from "./rendering/toolbar/tools/filter-command-tool.directive";
import * as i45 from "./rendering/toolbar/tools/group-command-tool.directive";
import * as i46 from "./rendering/header/header.component";
import * as i47 from "./rendering/header/header-template.directive";
import * as i48 from "./column-resizing/column-handle.directive";
import * as i49 from "./selection/selectall-checkbox.directive";
import * as i50 from "./rendering/footer/footer.component";
import * as i51 from "@progress/kendo-angular-pager";
import * as i52 from "@progress/kendo-angular-toolbar";
import * as i53 from "./filtering/filter-row.component";
import * as i54 from "./filtering/cell/filter-cell.component";
import * as i55 from "./filtering/cell/filter-cell-template.directive";
import * as i56 from "./filtering/cell/string-filter-cell.component";
import * as i57 from "./filtering/cell/numeric-filter-cell.component";
import * as i58 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i59 from "./filtering/cell/boolean-filter-cell.component";
import * as i60 from "./filtering/cell/filter-cell-host.directive";
import * as i61 from "./filtering/cell/filter-cell-wrapper.component";
import * as i62 from "./filtering/cell/date-filter-cell.component";
import * as i63 from "./filtering/cell/filter-cell-operators.component";
import * as i64 from "./filtering/operators/contains-filter-operator.component";
import * as i65 from "./filtering/operators/not-contains-filter-operator.component";
import * as i66 from "./filtering/operators/ends-with-filter-operator.component";
import * as i67 from "./filtering/operators/eq-filter-operator.component";
import * as i68 from "./filtering/operators/is-empty-filter-operator.component";
import * as i69 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i70 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i71 from "./filtering/operators/isnull-filter-operator.component";
import * as i72 from "./filtering/operators/neq-filter-operator.component";
import * as i73 from "./filtering/operators/starts-with-filter-operator.component";
import * as i74 from "./filtering/operators/gt-filter-operator.component";
import * as i75 from "./filtering/operators/gte-filter-operator.component";
import * as i76 from "./filtering/operators/lt-filter-operator.component";
import * as i77 from "./filtering/operators/lte-filter-operator.component";
import * as i78 from "./filtering/operators/after-filter-operator.component";
import * as i79 from "./filtering/operators/after-eq-filter-operator.component";
import * as i80 from "./filtering/operators/before-eq-filter-operator.component";
import * as i81 from "./filtering/operators/before-filter-operator.component";
import * as i82 from "./filtering/filter-input.directive";
import * as i83 from "./filtering/menu/filter-menu.component";
import * as i84 from "./filtering/menu/filter-menu-container.component";
import * as i85 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i86 from "./filtering/menu/string-filter-menu-input.component";
import * as i87 from "./filtering/menu/string-filter-menu.component";
import * as i88 from "./filtering/menu/filter-menu-template.directive";
import * as i89 from "./filtering/menu/numeric-filter-menu.component";
import * as i90 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i91 from "./filtering/menu/date-filter-menu-input.component";
import * as i92 from "./filtering/menu/date-filter-menu.component";
import * as i93 from "./filtering/menu/filter-menu-host.directive";
import * as i94 from "./filtering/menu/boolean-filter-menu.component";
import * as i95 from "./filtering/menu/filter-menu-dropdownlist.directive";
import * as i96 from "./filtering/menu/filter-radio-button.directive";
import * as i97 from "./column-menu/column-chooser-item-checked.directive";
import * as i98 from "./column-menu/column-list.component";
import * as i99 from "./column-menu/column-chooser.component";
import * as i100 from "./rendering/toolbar/tools/column-chooser-tool.directive";
import * as i101 from "./column-menu/column-menu-chooser.component";
import * as i102 from "./column-menu/column-menu-filter.component";
import * as i103 from "./column-menu/column-menu-item.component";
import * as i104 from "./column-menu/column-menu-item-content-template.directive";
import * as i105 from "./column-menu/column-menu-sort.component";
import * as i106 from "./column-menu/column-menu.component";
import * as i107 from "./column-menu/column-menu-lock.component";
import * as i108 from "./column-menu/column-menu-template.directive";
import * as i109 from "./column-menu/column-menu-container.component";
import * as i110 from "./column-menu/column-menu-item.directive";
import * as i111 from "./column-menu/column-menu-stick.component";
import * as i112 from "./column-menu/column-menu-position.component";
import * as i113 from "./column-menu/column-menu-autosize.component";
import * as i114 from "./column-menu/column-menu-autosize-all.component";
import * as i115 from "./grid.component";
import * as i116 from "./rendering/list.component";
import * as i117 from "./rendering/toolbar/toolbar.component";
import * as i118 from "./localization/localized-messages.directive";
import * as i119 from "./localization/custom-messages.component";
import * as i120 from "./databinding.directive";
import * as i121 from "./rendering/toolbar/toolbar-template.directive";
import * as i122 from "./selection/selection.directive";
import * as i123 from "./editing-directives/template-editing.directive";
import * as i124 from "./editing-directives/reactive-editing.directive";
import * as i125 from "./editing-directives/in-cell-editing.directive";
import * as i126 from "./editing-directives/external-editing.directive";
import * as i127 from "./rendering/details-expand.directive";
import * as i128 from "./rendering/groups-expand.directive";
import * as i129 from "./grouping/group-scroll-binding.directive";
import * as i130 from "./selection/marquee.directive";
import * as i131 from "./rendering/common/spacer.component";
import * as i132 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i133 from "./aggregates/status-bar.component";
import * as i134 from "./aggregates/status-bar-template.directive";
import * as i135 from "./common/clipboard.directive";
import * as i136 from "./editing/form/form.component";
import * as i137 from "./editing/form/dialog-form.component";
import * as i138 from "./editing/form/form-formfield.component";
import * as i139 from "./state-management/undo-redo.directive";
import * as i140 from "./state-management/undo-command-tool";
import * as i141 from "./state-management/redo-command-tool";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Grid component.
 *
 * @example
 *
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { GridModule } from '@progress/kendo-angular-grid';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, GridModule],
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * ```
 */
export class GridModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: GridModule, imports: [i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.RowDragHandleTemplateDirective, i26.RowDragHintTemplateDirective, i27.TableBodyComponent, i28.NoRecordsTemplateDirective, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i35.AddCommandToolbarDirective, i36.EditCommandToolbarDirective, i37.SaveCommandToolbarDirective, i38.RemoveCommandToolbarDirective, i39.CancelCommandToolbarDirective, i40.CellLoadingTemplateDirective, i41.LoadingTemplateDirective, i42.RowReorderColumnComponent, i43.SortCommandToolbarDirective, i44.FilterCommandToolbarDirective, i45.GroupCommandToolbarDirective, i46.HeaderComponent, i47.HeaderTemplateDirective, i48.ColumnHandleDirective, i49.SelectAllCheckboxDirective, i50.FooterComponent, i51.CustomMessagesComponent, i51.PagerFocusableDirective, i51.PagerInfoComponent, i51.PagerInputComponent, i51.PagerNextButtonsComponent, i51.PagerNumericButtonsComponent, i51.PagerPageSizesComponent, i51.PagerPrevButtonsComponent, i51.PagerTemplateDirective, i51.PagerComponent, i51.PagerSpacerComponent, i52.ToolBarComponent, i52.ToolbarCustomMessagesComponent, i52.ToolBarButtonComponent, i52.ToolBarButtonGroupComponent, i52.ToolBarDropDownButtonComponent, i52.ToolBarSeparatorComponent, i52.ToolBarSpacerComponent, i52.ToolBarSplitButtonComponent, i52.ToolBarToolComponent, i53.FilterRowComponent, i54.FilterCellComponent, i55.FilterCellTemplateDirective, i56.StringFilterCellComponent, i57.NumericFilterCellComponent, i58.AutoCompleteFilterCellComponent, i59.BooleanFilterCellComponent, i60.FilterCellHostDirective, i61.FilterCellWrapperComponent, i62.DateFilterCellComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i63.FilterCellOperatorsComponent, i64.ContainsFilterOperatorComponent, i65.DoesNotContainFilterOperatorComponent, i66.EndsWithFilterOperatorComponent, i67.EqualFilterOperatorComponent, i68.IsEmptyFilterOperatorComponent, i69.IsNotEmptyFilterOperatorComponent, i70.IsNotNullFilterOperatorComponent, i71.IsNullFilterOperatorComponent, i72.NotEqualFilterOperatorComponent, i73.StartsWithFilterOperatorComponent, i74.GreaterFilterOperatorComponent, i75.GreaterOrEqualToFilterOperatorComponent, i76.LessFilterOperatorComponent, i77.LessOrEqualToFilterOperatorComponent, i78.AfterFilterOperatorComponent, i79.AfterEqFilterOperatorComponent, i80.BeforeEqFilterOperatorComponent, i81.BeforeFilterOperatorComponent, i82.FilterInputDirective, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i63.FilterCellOperatorsComponent, i64.ContainsFilterOperatorComponent, i65.DoesNotContainFilterOperatorComponent, i66.EndsWithFilterOperatorComponent, i67.EqualFilterOperatorComponent, i68.IsEmptyFilterOperatorComponent, i69.IsNotEmptyFilterOperatorComponent, i70.IsNotNullFilterOperatorComponent, i71.IsNullFilterOperatorComponent, i72.NotEqualFilterOperatorComponent, i73.StartsWithFilterOperatorComponent, i74.GreaterFilterOperatorComponent, i75.GreaterOrEqualToFilterOperatorComponent, i76.LessFilterOperatorComponent, i77.LessOrEqualToFilterOperatorComponent, i78.AfterFilterOperatorComponent, i79.AfterEqFilterOperatorComponent, i80.BeforeEqFilterOperatorComponent, i81.BeforeFilterOperatorComponent, i82.FilterInputDirective, i83.FilterMenuComponent, i84.FilterMenuContainerComponent, i85.FilterMenuInputWrapperComponent, i86.StringFilterMenuInputComponent, i87.StringFilterMenuComponent, i88.FilterMenuTemplateDirective, i89.NumericFilterMenuComponent, i90.NumericFilterMenuInputComponent, i91.DateFilterMenuInputComponent, i92.DateFilterMenuComponent, i93.FilterMenuHostDirective, i94.BooleanFilterMenuComponent, i95.FilterMenuDropDownListDirective, i96.BooleanFilterRadioButtonDirective, i97.ColumnMenuChooserItemCheckedDirective, i98.ColumnListComponent, i99.ColumnChooserComponent, i100.ColumnChooserToolbarDirective, i101.ColumnMenuChooserComponent, i102.ColumnMenuFilterComponent, i103.ColumnMenuItemComponent, i104.ColumnMenuItemContentTemplateDirective, i105.ColumnMenuSortComponent, i106.ColumnMenuComponent, i107.ColumnMenuLockComponent, i108.ColumnMenuTemplateDirective, i109.ColumnMenuContainerComponent, i110.ColumnMenuItemDirective, i111.ColumnMenuStickComponent, i112.ColumnMenuPositionComponent, i113.ColumnMenuAutoSizeColumnComponent, i114.ColumnMenuAutoSizeAllColumnsComponent, i115.GridComponent, i116.ListComponent, i117.ToolbarComponent, i118.LocalizedMessagesDirective, i119.CustomMessagesComponent, i120.DataBindingDirective, i121.ToolbarTemplateDirective, i122.SelectionDirective, i123.TemplateEditingDirective, i124.ReactiveEditingDirective, i125.InCellEditingDirective, i126.ExternalEditingDirective, i127.ExpandDetailsDirective, i128.ExpandGroupDirective, i129.GroupBindingDirective, i130.GridMarqueeDirective, i131.GridSpacerComponent, i132.GridToolbarFocusableDirective, i133.StatusBarComponent, i134.StatusBarTemplateDirective, i135.GridClipboardDirective, i136.FormComponent, i137.DialogFormComponent, i138.FormFormFieldComponent, i139.UndoRedoDirective, i52.ToolBarComponent, i52.ToolbarCustomMessagesComponent, i52.ToolBarButtonComponent, i52.ToolBarButtonGroupComponent, i52.ToolBarDropDownButtonComponent, i52.ToolBarSeparatorComponent, i52.ToolBarSpacerComponent, i52.ToolBarSplitButtonComponent, i52.ToolBarToolComponent, TableDirective,
            UndoCommandToolbarDirective,
            RedoCommandToolbarDirective], exports: [i115.GridComponent, i121.ToolbarTemplateDirective, i117.ToolbarComponent, i131.GridSpacerComponent, i134.StatusBarTemplateDirective, i120.DataBindingDirective, i122.SelectionDirective, i119.CustomMessagesComponent, i129.GroupBindingDirective, i123.TemplateEditingDirective, i124.ReactiveEditingDirective, i125.InCellEditingDirective, i126.ExternalEditingDirective, i127.ExpandDetailsDirective, i128.ExpandGroupDirective, i132.GridToolbarFocusableDirective, i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.RowDragHandleTemplateDirective, i26.RowDragHintTemplateDirective, i27.TableBodyComponent, i28.NoRecordsTemplateDirective, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i35.AddCommandToolbarDirective, i36.EditCommandToolbarDirective, i37.SaveCommandToolbarDirective, i38.RemoveCommandToolbarDirective, i39.CancelCommandToolbarDirective, i40.CellLoadingTemplateDirective, i41.LoadingTemplateDirective, i42.RowReorderColumnComponent, i43.SortCommandToolbarDirective, i44.FilterCommandToolbarDirective, i45.GroupCommandToolbarDirective, i46.HeaderComponent, i47.HeaderTemplateDirective, i48.ColumnHandleDirective, i49.SelectAllCheckboxDirective, i53.FilterRowComponent, i54.FilterCellComponent, i55.FilterCellTemplateDirective, i56.StringFilterCellComponent, i57.NumericFilterCellComponent, i58.AutoCompleteFilterCellComponent, i59.BooleanFilterCellComponent, i60.FilterCellHostDirective, i61.FilterCellWrapperComponent, i62.DateFilterCellComponent, i63.FilterCellOperatorsComponent, i64.ContainsFilterOperatorComponent, i65.DoesNotContainFilterOperatorComponent, i66.EndsWithFilterOperatorComponent, i67.EqualFilterOperatorComponent, i68.IsEmptyFilterOperatorComponent, i69.IsNotEmptyFilterOperatorComponent, i70.IsNotNullFilterOperatorComponent, i71.IsNullFilterOperatorComponent, i72.NotEqualFilterOperatorComponent, i73.StartsWithFilterOperatorComponent, i74.GreaterFilterOperatorComponent, i75.GreaterOrEqualToFilterOperatorComponent, i76.LessFilterOperatorComponent, i77.LessOrEqualToFilterOperatorComponent, i78.AfterFilterOperatorComponent, i79.AfterEqFilterOperatorComponent, i80.BeforeEqFilterOperatorComponent, i81.BeforeFilterOperatorComponent, i83.FilterMenuComponent, i84.FilterMenuContainerComponent, i85.FilterMenuInputWrapperComponent, i86.StringFilterMenuInputComponent, i87.StringFilterMenuComponent, i88.FilterMenuTemplateDirective, i89.NumericFilterMenuComponent, i90.NumericFilterMenuInputComponent, i91.DateFilterMenuInputComponent, i92.DateFilterMenuComponent, i93.FilterMenuHostDirective, i94.BooleanFilterMenuComponent, i95.FilterMenuDropDownListDirective, i96.BooleanFilterRadioButtonDirective, i99.ColumnChooserComponent, i100.ColumnChooserToolbarDirective, i102.ColumnMenuFilterComponent, i103.ColumnMenuItemComponent, i104.ColumnMenuItemContentTemplateDirective, i105.ColumnMenuSortComponent, i107.ColumnMenuLockComponent, i111.ColumnMenuStickComponent, i112.ColumnMenuPositionComponent, i101.ColumnMenuChooserComponent, i108.ColumnMenuTemplateDirective, i109.ColumnMenuContainerComponent, i110.ColumnMenuItemDirective, i106.ColumnMenuComponent, i113.ColumnMenuAutoSizeColumnComponent, i114.ColumnMenuAutoSizeAllColumnsComponent, i135.GridClipboardDirective, i139.UndoRedoDirective, i140.UndoCommandToolbarDirective, i141.RedoCommandToolbarDirective, i52.ToolBarComponent, i52.ToolbarCustomMessagesComponent, i52.ToolBarButtonComponent, i52.ToolBarButtonGroupComponent, i52.ToolBarDropDownButtonComponent, i52.ToolBarSeparatorComponent, i52.ToolBarSpacerComponent, i52.ToolBarSplitButtonComponent, i52.ToolBarToolComponent, i51.CustomMessagesComponent, i51.PagerFocusableDirective, i51.PagerInfoComponent, i51.PagerInputComponent, i51.PagerNextButtonsComponent, i51.PagerNumericButtonsComponent, i51.PagerPageSizesComponent, i51.PagerPrevButtonsComponent, i51.PagerTemplateDirective, i51.PagerComponent, i51.PagerSpacerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, providers: [
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            NavigationService
        ], imports: [i4.GroupHeaderComponent, i5.GroupPanelComponent, i27.TableBodyComponent, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i46.HeaderComponent, i51.CustomMessagesComponent, i51.PagerInfoComponent, i51.PagerInputComponent, i51.PagerNextButtonsComponent, i51.PagerNumericButtonsComponent, i51.PagerPageSizesComponent, i51.PagerPrevButtonsComponent, i51.PagerComponent, i51.PagerSpacerComponent, i52.ToolBarComponent, i52.ToolbarCustomMessagesComponent, i52.ToolBarButtonComponent, i52.ToolBarButtonGroupComponent, i52.ToolBarDropDownButtonComponent, i52.ToolBarSeparatorComponent, i52.ToolBarSpacerComponent, i52.ToolBarSplitButtonComponent, i56.StringFilterCellComponent, i57.NumericFilterCellComponent, i58.AutoCompleteFilterCellComponent, i59.BooleanFilterCellComponent, i61.FilterCellWrapperComponent, i62.DateFilterCellComponent, i63.FilterCellOperatorsComponent, i63.FilterCellOperatorsComponent, i83.FilterMenuComponent, i84.FilterMenuContainerComponent, i85.FilterMenuInputWrapperComponent, i86.StringFilterMenuInputComponent, i87.StringFilterMenuComponent, i89.NumericFilterMenuComponent, i90.NumericFilterMenuInputComponent, i91.DateFilterMenuInputComponent, i92.DateFilterMenuComponent, i94.BooleanFilterMenuComponent, i98.ColumnListComponent, i99.ColumnChooserComponent, i101.ColumnMenuChooserComponent, i102.ColumnMenuFilterComponent, i103.ColumnMenuItemComponent, i105.ColumnMenuSortComponent, i106.ColumnMenuComponent, i107.ColumnMenuLockComponent, i111.ColumnMenuStickComponent, i112.ColumnMenuPositionComponent, i113.ColumnMenuAutoSizeColumnComponent, i114.ColumnMenuAutoSizeAllColumnsComponent, i115.GridComponent, i116.ListComponent, i136.FormComponent, i137.DialogFormComponent, i138.FormFormFieldComponent, i52.ToolBarComponent, i52.ToolbarCustomMessagesComponent, i52.ToolBarButtonComponent, i52.ToolBarButtonGroupComponent, i52.ToolBarDropDownButtonComponent, i52.ToolBarSeparatorComponent, i52.ToolBarSpacerComponent, i52.ToolBarSplitButtonComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_EXPORTS, ...KENDO_TOOLBAR, ...KENDO_PAGER],
                    imports: [
                        ...KENDO_GRID_GROUP_EXPORTS,
                        ...KENDO_GRID_SHARED,
                        ...KENDO_GRID_BODY_EXPORTS,
                        ...KENDO_GRID_HEADER_EXPORTS,
                        ...KENDO_GRID_FOOTER_EXPORTS,
                        ...KENDO_PAGER,
                        ...KENDO_TOOLBAR,
                        ...KENDO_GRID_FILTER_ROW,
                        ...KENDO_GRID_FILTER_MENU,
                        ...KENDO_GRID_COLUMN_MENU_DECLARATIONS,
                        ...KENDO_GRID_DECLARATIONS,
                        ...KENDO_TOOLBAR,
                        TableDirective,
                        UndoCommandToolbarDirective,
                        RedoCommandToolbarDirective
                    ],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
