/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 as Renderer, NgZone } from '@angular/core';
import { Button } from '@progress/kendo-angular-buttons';
import { ContextService } from '../common/provider.service';
import { ExcelService } from './excel.service';
import * as i0 from "@angular/core";
/**
 * Represents the `export-to-Excel` command of the Grid. You can apply this
 * directive to any `button` element inside a
 * [ToolbarTemplate]({% slug api_grid_toolbartemplatedirective %}).
 * When the user clicks a button associated with the directive, the
 * [excelExport]({% slug api_grid_gridcomponent %}#toc-excelexport) event
 * fires ([see example]({% slug excelexport_grid %})).
 *
 * @example
 * ```html
 * <kendo-grid>
 *      <ng-template kendoGridToolbarTemplate>
 *          <button kendoGridExcelCommand>Export to Excel</button>
 *      </ng-template>
 *      <kendo-grid-excel fileName="Grid.xlsx">
 *      </kendo-grid-excel>
 * </kendo-grid>
 * ```
 */
export declare class ExcelCommandDirective extends Button {
    private excelService;
    /**
     * @hidden
     */
    onClick(e: any): void;
    /**
     * @hidden
     */
    get excelClass(): boolean;
    constructor(excelService: ExcelService, element: ElementRef, renderer: Renderer, ctx: ContextService, ngZone: NgZone);
    static ɵfac: i0.ɵɵFactoryDeclaration<ExcelCommandDirective, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ExcelCommandDirective, "[kendoGridExcelCommand]", never, {}, {}, never, ["*"], true, never>;
}
