/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { FilterService } from '../filter.service';
import { BooleanFilterComponent } from '../boolean-filter.component';
import { GridSize } from '../../common/size-options';
import { SizingOptionsService } from '../../layout/sizing-options.service';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a Boolean filter-cell component.
 * See the article about the [built-in filter components](slug:filter_row#toc-built-in-filter-row-components).
 *
 * @example
 *
 * ```html
 * <kendo-grid-column field="Discontinued">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-boolean-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *     </kendo-grid-boolean-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class BooleanFilterCellComponent extends BooleanFilterComponent {
    private cd;
    /**
     * @hidden
     */
    size: GridSize;
    private subs;
    constructor(filterService: FilterService, ctx: ContextService, cd: ChangeDetectorRef, sizingService: SizingOptionsService);
    ngOnDestroy(): void;
    protected localizationChange(): void;
    /**
     * @hidden
     */
    get columnLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<BooleanFilterCellComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BooleanFilterCellComponent, "kendo-grid-boolean-filter-cell", never, {}, {}, never, never, true, never>;
}
