/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FilterService } from '../filter.service';
import { DateFilterComponent } from '../date-filter.component';
import { SizingOptionsService } from '../../layout/sizing-options.service';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a [DatePicker](slug:overview_datepicker) filter-cell component.
 * See the article about the [built-in filter components](slug:filter_row#toc-built-in-filter-row-components).
 *
 * @example
 *
 * ```html
 * <kendo-grid-column field="FirstOrderedOn">
 *   <ng-template kendoGridFilterCellTemplate let-filter let-column="column">
 *     <kendo-grid-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *     </kendo-grid-date-filter-cell>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class DateFilterCellComponent extends DateFilterComponent {
    protected ctx: ContextService;
    /**
     * Determines if the drop-down filter operators will be displayed. The default value is `true`.
     * @type {boolean}
     * @default true
     */
    showOperators: boolean;
    private subs;
    constructor(filterService: FilterService, ctx: ContextService, sizingService: SizingOptionsService);
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    messageFor(key: string): string;
    /**
     * @hidden
     */
    get columnLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateFilterCellComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateFilterCellComponent, "kendo-grid-date-filter-cell", never, { "showOperators": { "alias": "showOperators"; "required": false; }; }, {}, never, never, true, never>;
}
