/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { MenuTabbingService } from './menu-tabbing.service';
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { FilterService } from '../filter.service';
import { DateFilterComponent } from '../date-filter.component';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a date filter-menu component.
 *
 * @example
 * ```html
 * <kendo-grid-column field="FirstOrderedOn">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-grid-date-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class DateFilterMenuComponent extends DateFilterComponent {
    logicOperators: Array<{
        text: string;
        value: "and" | "or";
    }>;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * The current menu filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * Determines if the inputs of second criteria will be displayed.
     * @default true
     */
    extra: boolean;
    /**
     * The `FilterService` instance which is responsible for handling the changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    constructor(ctx: ContextService);
    get firstFilter(): FilterDescriptor;
    get secondFilter(): FilterDescriptor;
    logicChange(value: 'and' | 'or'): void;
    get filterMenuDropDownLabel(): string;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateFilterMenuComponent, "kendo-grid-date-filter-menu", never, { "filter": { "alias": "filter"; "required": false; }; "extra": { "alias": "extra"; "required": false; }; "filterService": { "alias": "filterService"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; }, {}, never, never, true, never>;
}
