/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { MenuTabbingService } from './menu-tabbing.service';
import { OnInit, EventEmitter, OnDestroy, ChangeDetectorRef } from '@angular/core';
import { CompositeFilterDescriptor, FilterDescriptor } from "@progress/kendo-data-query";
import { ColumnComponent } from "../../columns/column.component";
import { FilterService } from "../filter.service";
import { ContextService } from '../../common/provider.service';
import { AdaptiveGridService } from '../../common/adaptiveness.service';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare const validFilters: ({ value, operator }: FilterDescriptor) => boolean;
/**
 * @hidden
 */
export declare const parentLogicOfDefault: (filter: any, field: any, def?: string) => any;
/**
 * @hidden
 */
export declare class FilterMenuContainerComponent implements OnInit, OnDestroy {
    protected parentService: FilterService;
    childService: FilterService;
    ctx: ContextService;
    protected cd: ChangeDetectorRef;
    private adaptiveGridService;
    close: EventEmitter<any>;
    /**
     * The column with which the filter is associated.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * @hidden
     */
    isLast: boolean;
    /**
     * @hidden
     */
    isExpanded: boolean;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    /**
     * The current root filter.
     * @type {CompositeFilterDescriptor}
     */
    set filter(value: CompositeFilterDescriptor);
    get filter(): CompositeFilterDescriptor;
    /**
     * @hidden
     */
    actionsClass: string;
    get childFilter(): CompositeFilterDescriptor;
    private resetButton;
    private filterButton;
    private _childFilter;
    private subscription;
    private _templateContext;
    private _filter;
    constructor(parentService: FilterService, childService: FilterService, ctx: ContextService, cd: ChangeDetectorRef, menuTabbingService: MenuTabbingService, adaptiveGridService: AdaptiveGridService);
    ngOnInit(): void;
    ngAfterViewChecked(): void;
    ngOnDestroy(): void;
    get disabled(): boolean;
    get templateContext(): any;
    get hasTemplate(): boolean;
    submit(): boolean;
    reset(): void;
    resetChildFilters(): void;
    onTab(e: Event, buttonType: string): void;
    get clearText(): string;
    get filterText(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterMenuContainerComponent, [{ skipSelf: true; }, null, null, null, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterMenuContainerComponent, "kendo-grid-filter-menu-container", never, { "column": { "alias": "column"; "required": false; }; "isLast": { "alias": "isLast"; "required": false; }; "isExpanded": { "alias": "isExpanded"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "actionsClass": { "alias": "actionsClass"; "required": false; }; }, { "close": "close"; }, never, never, true, never>;
}
