/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit } from '@angular/core';
import { ColumnComponent } from '../columns/column.component';
import { FilterService } from './filter.service';
import { FilterDescriptor } from '@progress/kendo-data-query';
import { BaseFilterCellComponent } from './base-filter-cell.component';
import { FilterComponent } from './filter-component.interface';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a base numeric filter component.
 */
export declare abstract class NumericFilterComponent extends BaseFilterCellComponent implements FilterComponent, OnInit {
    protected ctx: ContextService;
    /**
     * The column with which the filter is associated.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * The default filter operator.
     * @type {string}
     * @default 'eq'
     */
    operator: string;
    /**
     * Specifies the value that is used to increment or decrement the component value.
     * @type {numeric}
     * @default 1
     */
    step: number;
    /**
     * Specifies the smallest value that is valid.
     * @type {number}
     */
    min: number;
    /**
     * Specifies the greatest value that is valid.
     * @type {number}
     */
    max: number;
    /**
     * Specifies whether the **Up** and **Down** spin buttons will be rendered.
     * @type {boolean}
     * @default true
     */
    spinners: boolean;
    /**
     * Specifies the number precision applied to the component value when it is focused.
     * If the user enters a number with a greater precision than is currently configured, the component value is rounded.
     *
     * @type {number}
     */
    decimals: number;
    /**
     * Specifies the number format used when the component is not focused.
     * By default, the `column.format` value is used (if set).
     */
    get format(): string;
    set format(value: string);
    /**
     * The current filter for the associated column field.
     * @readonly
     * @type {FilterDescriptor}
     */
    get currentFilter(): FilterDescriptor;
    /**
     * The current filter operator for the associated column field.
     * @readonly
     * @type {string}
     */
    get currentOperator(): string;
    private get columnFormat();
    private _format;
    private subscription;
    constructor(filterService: FilterService, ctx: ContextService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumericFilterComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NumericFilterComponent, never, never, { "column": { "alias": "column"; "required": false; }; "operator": { "alias": "operator"; "required": false; }; "step": { "alias": "step"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "spinners": { "alias": "spinners"; "required": false; }; "decimals": { "alias": "decimals"; "required": false; }; "format": { "alias": "format"; "required": false; }; }, {}, never, never, false, never>;
}
