/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ColumnComponent } from '../columns/column.component';
import { FilterService } from './filter.service';
import { FilterDescriptor } from '@progress/kendo-data-query';
import { BaseFilterCellComponent } from './base-filter-cell.component';
import { FilterComponent } from './filter-component.interface';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a base string filter component.
 */
export declare abstract class StringFilterComponent extends BaseFilterCellComponent implements FilterComponent {
    protected ctx: ContextService;
    /**
     * The column with which the filter is associated.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * The default filter operator.
     * @type {string}
     * @default 'contains'
     */
    operator: string;
    /**
     * The current filter for the associated column field.
     * @readonly
     * @type {FilterDescriptor}
     */
    get currentFilter(): FilterDescriptor;
    /**
     * The current filter operator for the associated column field.
     * @readonly
     * @type {string}
     */
    get currentOperator(): string;
    private subscription;
    constructor(filterService: FilterService, ctx: ContextService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<StringFilterComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<StringFilterComponent, never, never, { "column": { "alias": "column"; "required": false; }; "operator": { "alias": "operator"; "required": false; }; }, {}, never, never, false, never>;
}
