/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the possible navigable sections of the Grid ([see example]({% slug keyboard_navigation_grid %}#toc-navigable-sections)).
 *
 * The available values are:
 * * `pager`&mdash;Includes the Grid pager and its internal elements
 * * `table`&mdash;Includes the Grid pager and its internal elements
 * * `toolbar`&mdash;Includes the Grid toolbars and the group panel when the Grid is groupable.
 *
 * @xample
 * ```html
 * <kendo-grid [navigable]="['pager', 'toolbar']"> </kendo-grid>
 * ```
 */
export type GridNavigableSection = 'pager' | 'table' | 'toolbar';
/**
 * Represents the type of the Grid [`navigable`]({% slug api_grid_gridcomponent %}#toc-navigable) property.
 *
 * The available values are:
 * * `boolean`
 * * [`GridNavigableSection`](slug:api_grid_gridnavigablesection)
 */
export type GridNavigableSettings = boolean | GridNavigableSection[];
