/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, OnDestroy } from '@angular/core';
import { GridComponent } from '../grid.component';
import { GroupRowArgs } from '../grouping/group-rows-args.interface';
import * as i0 from "@angular/core";
/**
 * A directive which controls the expanded state of the group rows
 * ([see example]({% slug groups_expanded_state_grid %}#toc-built-in-directive)).
 */
export declare class ExpandGroupDirective implements OnDestroy {
    protected grid: GridComponent;
    /**
     * Fires when the expandedGroupKeys are changed.
     */
    expandedGroupKeysChange: EventEmitter<any[]>;
    /**
     * Defines the item format that will be stored in the `expandedGroupKeys`
     * ([see example]({% slug groups_expanded_state_grid %}#toc-custom-group-key-format)).
     */
    get expandGroupBy(): string | ((group: GroupRowArgs) => any);
    set expandGroupBy(key: string | ((group: GroupRowArgs) => any));
    /**
     * Defines the collection that will store the expanded group keys.
     */
    get expandedGroupKeys(): any[];
    set expandedGroupKeys(expandedGroups: any[]);
    /**
     * Specifies if the group items should be initially expanded.
     * @default false
     */
    groupsInitiallyExpanded: boolean;
    private _expandGroupBy;
    private _expandedGroupKeys;
    private subscriptions;
    constructor(grid: GridComponent);
    ngOnDestroy(): void;
    protected get keyGetter(): any;
    /**
     * @hidden
     */
    isExpanded(groupArgs: GroupRowArgs): boolean;
    private getItemIndex;
    private toggleState;
    static ɵfac: i0.ɵɵFactoryDeclaration<ExpandGroupDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ExpandGroupDirective, "[kendoGridExpandGroupBy]", ["kendoGridExpandGroupBy"], { "expandGroupBy": { "alias": "kendoGridExpandGroupBy"; "required": false; }; "expandedGroupKeys": { "alias": "expandedGroupKeys"; "required": false; }; "groupsInitiallyExpanded": { "alias": "groupsInitiallyExpanded"; "required": false; }; }, { "expandedGroupKeysChange": "expandedGroupKeysChange"; }, never, never, true, never>;
}
