/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterViewInit, NgZone, OnDestroy, Renderer2 } from '@angular/core';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { PopupService } from '@progress/kendo-angular-popup';
import { ContextService } from '../../../common/provider.service';
import { SortService } from '../../../common/sort.service';
import { ColumnInfoService } from '../../../common/column-info.service';
import { AdaptiveGridService } from '../../../common/adaptiveness.service';
import { SortDescriptor } from '@progress/kendo-data-query';
import * as i0 from "@angular/core";
/**
 * Represents the toolbar tool for sorting columns of the Grid.
 * You can apply this directive to any `kendo-toolbar-button` element inside a
 * ToolbarComponent used in the Grid.
 *
 * When the user clicks the toolbar button that is associated with the directive, the
 * sort event is triggered.
 *
 * @example
 * ```html-no-run
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button text="Sort" kendoGridSortTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 * </kendo-grid>
 * ```
 */
export declare class SortCommandToolbarDirective implements AfterViewInit, OnDestroy {
    private host;
    private popupService;
    private ctx;
    private sortService;
    private columnInfoService;
    private ngZone;
    private renderer;
    private adaptiveGridService;
    private popupRef;
    private nextId;
    private toolSubs;
    private popupSubs;
    private actionSheetCloseSub;
    private removeClickListener;
    /**
     * @hidden
     */
    isSortingApplied(sort: SortDescriptor[]): boolean;
    constructor(host: ToolBarButtonComponent, popupService: PopupService, ctx: ContextService, sortService: SortService, columnInfoService: ColumnInfoService, ngZone: NgZone, renderer: Renderer2, adaptiveGridService: AdaptiveGridService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private onClick;
    private openPopup;
    private setPopupAttributes;
    private initPopupProperties;
    private closePopup;
    private get buttonElement();
    static ɵfac: i0.ɵɵFactoryDeclaration<SortCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SortCommandToolbarDirective, "[kendoGridSortTool]", never, {}, {}, never, never, true, never>;
}
