/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the column row reorder cell template of the Grid.
 * Helps to customize the content of the drag handle cells. To define the cell template, nest an `<ng-template>`
 * tag with the `kendoGridRowDragHandleTemplate` directive inside the `<kendo-grid-rowreorder-column>` tag.
 *
 * The template context is set to the current data item and the following additional fields are passed:
 * - `columnIndex`&mdash;The current column index. Use it as an alias for a template variable by utilizing the `let-columnIndex="columnIndex"` syntax.
 * - `rowIndex`&mdash;The provided data row index. Use it as an alias for a template variable by utilizing the `let-rowIndex="rowIndex"` syntax.
 *
 * @example
 * ```html
 * <kendo-grid [kendoGridBinding]="data" [rowReorderable]="true">
 *    <kendo-grid-rowreorder-column>
 *      <ng-template kendoGridRowDragHandleTemplate>
 *        <span>Drag here</span>
 *      </ng-template>
 *    </kendo-grid-rowreorder-column>
 *   <kendo-grid-column field="Field1"></kendo-grid-column>
 *   <kendo-grid-column field="Field2"></kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class RowDragHandleTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<RowDragHandleTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RowDragHandleTemplateDirective, "[kendoGridRowDragHandleTemplate]", never, {}, {}, never, never, true, never>;
}
