/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Subject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Arguments for the `scrollTo` method. Specifies to which row or column should the Grid scroll to.
 * [See example](slug:scrollmmodes_grid#toc-scrolling-to-a-specific-row-and-column).
 */
export interface ScrollRequest {
    /**
     * The row index to which the Grid should scroll to, considering `0` as first row.
     */
    row?: number;
    /**
     * The column index to which the Grid should scroll to, considering `0` as first column.
     */
    column?: number;
}
/**
 * Arguments for the `scrollToItem` method. Specifies to which data item and column should the Grid scroll to.
 * [See example](slug:scrollmmodes_grid#toc-scrolling-to-a-specific-item).
 */
export interface ScrollToItemRequest {
    /**
     * The property of the Grid data items that represents the unique ID of the item.
     */
    idField: string;
    /**
     * The value of the data item unique identifier.
     */
    id: any;
}
/**
 * @hidden
 */
export declare class ScrollRequestService {
    requests: Subject<{
        request: ScrollRequest | ScrollToItemRequest;
        adjustIndex?: boolean;
    }>;
    scrollTo(request: ScrollRequest, adjustIndex?: boolean): void;
    scrollToItem(request: ScrollToItemRequest): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ScrollRequestService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ScrollRequestService>;
}
