/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { State } from "@progress/kendo-data-query";
import { GridDataResult } from "../data/data.collection";
import { PreventableEvent } from "@progress/kendo-angular-common";
/**
 * Represent the state of each Grid column that can be changed by the user.
 */
export interface ColumnState {
    /**
     * The column identifier that is unique in the scope of its `GridComponent` owner.
     */
    id: string;
    /**
     * The column width in pixels.
     */
    width?: number;
    /**
     * The column visibility.
     */
    hidden?: boolean;
    /**
     * The column locked state.
     */
    locked?: boolean;
    /**
     * The column sticky state.
     */
    sticky?: boolean;
    orderIndex?: number;
}
/**
 * The state of the grid component.
 * It includes the current `State`, data, and columns state.
 */
export interface GridState extends State {
    columnsState?: ColumnState[];
    currentData?: Array<any> | GridDataResult | null;
}
/**
 * Arguments for the `undo` and `redo` events.
 */
export declare class UndoRedoEvent extends PreventableEvent {
    /**
     * The event data of the original action that triggered the state change.
     */
    readonly originalEvent: any;
    /**
     * The grid state and rendered data at the time of the action.
     */
    readonly gridState: GridState;
    /**
     * @hidden
     */
    constructor({ originalEvent, gridState }: any);
}
