/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { UndoRedoService } from './undo-redo.service';
import * as i0 from "@angular/core";
/**
 * Represents the command for triggering the redo action in the Grid.
 * You can apply this directive to any `kendo-toolbar-button` element inside a
 * ToolbarComponent used in the Grid.
 *
 * When the user clicks the toolbar button that is associated with the directive, the
 * [redo]({% slug api_grid_undoredodirective %}#toc-redo) event is triggered.
 *
 * @example
 * ```html-no-run
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button kendoGridRedoTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 * </kendo-grid>
 * ```
 */
export declare class RedoCommandToolbarDirective {
    private undoRedoService;
    private host;
    private subs;
    constructor(undoRedoService: UndoRedoService, host: ToolBarButtonComponent);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RedoCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RedoCommandToolbarDirective, "[kendoGridRedoTool]", never, {}, {}, never, never, true, never>;
}
